---
title: 카카오페이 계약 및 이용 시 필독 사항
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 카카오페이 계약 시 참고사항 (이용 시 필독)
  description: 카카오페이 계약 시 참고할 입점정책에 대한 설명입니다. 카카오페이 입점 제한 업종 및 정기결제 서비스를 위한 참고사항을 확인하세요.
  keywords:
    - 카카오페이
tags:
  - 카카오페이
  - 결제대행사 계약
pgCompanies:
  - 카카오페이
searchTags:
  - 카카오페이 입점제한 업종
  - 카카오페이 입점정책
datetime: 2024-01-25T15:00:00.000Z
---

### **카카오페이 입점정책**

- 계약서상에 인감 및 사인이 누락된 경우 계약 진행이 되지 않습니다.
- 신청서 상의 홈페이지 주소는 실제 카카오페이 결제 연동하실 사이트 주소(또는 APP 명칭)으로 작성 바랍니다.
- 사이트(또는 앱) 하단의 사업자 정보 노출은 필수입니다.\
  (상호, 사업자 번호, 대표자명, 사업장 주소지, 연락처(유선번호만 가능), 고객센터 이메일 주소)
- 결제할 상품이 등록되어 있어야 합니다.  (3개 이상, 컨텐츠 상품의 경우 업종에 따라 상이)
- 중개서비스 유형의 경우는 전자금융업자만 연동 가능하며, 전자금융업자가 아닌 경우 모든 책임 및 cs는 해당 몰에서 지는 조건으로 연동이 가능합니다.
- 재정산 업종 (ex.인터파크,티몬 등)인 경우 카카오페이 정책에 따라 전자지급결제대행업(PG업/전자금융업) 등록한 가맹점에 한하여 입점이 가능하나, '모든 거래에 대한 책임은 가맹점에 있다' 는 문구를 추가 기재 시 카카오페이 내부 심사 요청드려 볼 수 있습니다.
- 유사 투자자문업종(주식투자 정보제공 등)은 입점이 어려울 수 있습니다. \
  (참고 : 투자 정보제공보다는 단순히 입력한 데이터를 정제하여 제공하는 형태는 입점 가능한 사례가 있음)
- 실물 서비스의 경우, 배송기간 정보는 필수로 적용되어야 합니다.
- APP 서비스의 경우 앱스토어에 등록이 되어있어야 하며, 하단 사업자 정보 구비, 실 결제가 가능한 상태에서 카드사 심사 및 계약 진행이 가능합니다.

### **🚫 카카오페이 입점 제한 업종**



### **정기결제 서비스 이용을 원하시는 경우 참고사항**

- 카카오페이 계약서 작성 시 계약사항 정기결제 이용 여부 항목에 "이용"으로 기재 및 정기결제 대상 품목 항목에 판매하시는 서비스 유형(예시:애견용품) 기재 바랍니다.
- 정기결제 이용특약서 추가로 작성하여 신청 바랍니다.
